==> xoonips-3.41.tar.gz: xoonips-3.41/xoonips/filesearch/def_excel.php <==
<?php
// $Revision: 1.2.2.1.2.3 $
// ------------------------------------------------------------------------- //
//  XooNIps - Neuroinformatics Base Platform System                          //
//  Copyright (C) 2005-2008 RIKEN, Japan All rights reserved.                //
//  http://xoonips.sourceforge.jp/                                           //
// ------------------------------------------------------------------------- //
//  This program is free software; you can redistribute it and/or modify     //
//  it under the terms of the GNU General Public License as published by     //
//  the Free Software Foundation; either version 2 of the License, or        //
//  (at your option) any later version.                                      //
//                                                                           //
//  You may not change or alter any portion of this comment or credits       //
//  of supporting developers from this source code or any supporting         //
//  source code which is considered copyrighted (c) material of the          //
//  original comment or credit authors.                                      //
//                                                                           //
//  This program is distributed in the hope that it will be useful,          //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
//  GNU General Public License for more details.                             //
//                                                                           //
//  You should have received a copy of the GNU General Public License        //
//  along with this program; if not, write to the Free Software              //
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
// ------------------------------------------------------------------------- //
/**
 * definition file of MS-Excel file search
 */
// php-indent: disable
$module['class_name']    = 'XoonipsExcel';
$module['php_file_name'] = 'excel.php';
$module['name']          = 'excel';
$module['display_name']  = 'excel';

$module['mime_type']     = array( 'application/vnd.ms-excel', 'application/msword' );
$module['extensions']    = array( 'xls', 'xlt', 'xlm', 'xld', 'xla', 'xlc', 'xlw', 'xll' );
$module['version']       = '1.0';
// php-indent: enable
?>

==> xoonips-3.46a.tar.gz: xoonips-3.46a/xoonips/filesearch/def_excel.php <==
<?php
// $Revision: 1.2.2.1.2.5 $
// ------------------------------------------------------------------------- //
//  XooNIps - Neuroinformatics Base Platform System                          //
//  Copyright (C) 2005-2011 RIKEN, Japan All rights reserved.                //
//  http://xoonips.sourceforge.jp/                                           //
// ------------------------------------------------------------------------- //
//  This program is free software; you can redistribute it and/or modify     //
//  it under the terms of the GNU General Public License as published by     //
//  the Free Software Foundation; either version 2 of the License, or        //
//  (at your option) any later version.                                      //
//                                                                           //
//  You may not change or alter any portion of this comment or credits       //
//  of supporting developers from this source code or any supporting         //
//  source code which is considered copyrighted (c) material of the          //
//  original comment or credit authors.                                      //
//                                                                           //
//  This program is distributed in the hope that it will be useful,          //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
//  GNU General Public License for more details.                             //
//                                                                           //
//  You should have received a copy of the GNU General Public License        //
//  along with this program; if not, write to the Free Software              //
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
// ------------------------------------------------------------------------- //
/**
 * definition file of MS-Excel file search
 */
// php-indent: disable
$module['class_name']    = 'XooNIpsFileSearchPluginEXCEL';
$module['php_file_name'] = 'excel.php';
$module['name']          = 'excel';
$module['display_name']  = 'MS-Excel 95/97/2000/XP/2003';
$module['mime_type']     = array( 'application/vnd.ms-excel', 'application/msword' );
$module['extensions']    = array( 'xls', 'xlt', 'xlm', 'xld', 'xla', 'xlc', 'xlw', 'xll' );
$module['version']       = '2.0';
// php-indent: enable
?>
